@@ -1,6 +1,6 @@
 /*========================== begin_copyright_notice ============================
 
-Copyright (C) 2019-2021 Intel Corporation
+Copyright (C) 2019-2023 Intel Corporation
 
 SPDX-License-Identifier: MIT
 
@@ -97,8 +97,10 @@ enum IIT_Info {
   IIT_VARARG = 29,
   IIT_HALF_VEC_ARG = 30,
   IIT_SAME_VEC_WIDTH_ARG = 31,
+#if VC_INTR_LLVM_VERSION_MAJOR < 18
   IIT_PTR_TO_ARG = 32,
   IIT_PTR_TO_ELT = 33,
+#endif
   IIT_VEC_OF_ANYPTRS_TO_ELT = 34,
   IIT_I128 = 35,
   IIT_V512 = 36,
@@ -109,6 +111,15 @@ enum IIT_Info {
   IIT_F128 = 41
 };
 
+static Intrinsic::IITDescriptor getVector(unsigned Width) {
+  using namespace Intrinsic;
+#if VC_INTR_LLVM_VERSION_MAJOR >= 11
+  return IITDescriptor::getVector(Width, false);
+#else
+  return IITDescriptor::get(IITDescriptor::Vector, Width);
+#endif
+}
+
 static void
 DecodeIITType(unsigned &NextElt, ArrayRef<unsigned char> Infos,
               SmallVectorImpl<Intrinsic::IITDescriptor> &OutputTable) {
@@ -164,39 +175,39 @@ DecodeIITType(unsigned &NextElt, ArrayRef<unsigned char> Infos,
     OutputTable.push_back(IITDescriptor::get(IITDescriptor::Integer, 128));
     return;
   case IIT_V1:
-    OutputTable.push_back(IITDescriptor::get(IITDescriptor::Vector, 1));
+    OutputTable.push_back(getVector(1));
     DecodeIITType(NextElt, Infos, OutputTable);
     return;
   case IIT_V2:
-    OutputTable.push_back(IITDescriptor::get(IITDescriptor::Vector, 2));
+    OutputTable.push_back(getVector(2));
     DecodeIITType(NextElt, Infos, OutputTable);
     return;
   case IIT_V4:
-    OutputTable.push_back(IITDescriptor::get(IITDescriptor::Vector, 4));
+    OutputTable.push_back(getVector(4));
     DecodeIITType(NextElt, Infos, OutputTable);
     return;
   case IIT_V8:
-    OutputTable.push_back(IITDescriptor::get(IITDescriptor::Vector, 8));
+    OutputTable.push_back(getVector(8));
     DecodeIITType(NextElt, Infos, OutputTable);
     return;
   case IIT_V16:
-    OutputTable.push_back(IITDescriptor::get(IITDescriptor::Vector, 16));
+    OutputTable.push_back(getVector(16));
     DecodeIITType(NextElt, Infos, OutputTable);
     return;
   case IIT_V32:
-    OutputTable.push_back(IITDescriptor::get(IITDescriptor::Vector, 32));
+    OutputTable.push_back(getVector(32));
     DecodeIITType(NextElt, Infos, OutputTable);
     return;
   case IIT_V64:
-    OutputTable.push_back(IITDescriptor::get(IITDescriptor::Vector, 64));
+    OutputTable.push_back(getVector(64));
     DecodeIITType(NextElt, Infos, OutputTable);
     return;
   case IIT_V512:
-    OutputTable.push_back(IITDescriptor::get(IITDescriptor::Vector, 512));
+    OutputTable.push_back(getVector(512));
     DecodeIITType(NextElt, Infos, OutputTable);
     return;
   case IIT_V1024:
-    OutputTable.push_back(IITDescriptor::get(IITDescriptor::Vector, 1024));
+    OutputTable.push_back(getVector(1024));
     DecodeIITType(NextElt, Infos, OutputTable);
     return;
   case IIT_PTR:
@@ -238,6 +249,7 @@ DecodeIITType(unsigned &NextElt, ArrayRef<unsigned char> Infos,
                                              ArgInfo));
     return;
   }
+#if VC_INTR_LLVM_VERSION_MAJOR < 17
   case IIT_PTR_TO_ARG: {
     unsigned ArgInfo = (NextElt == Infos.size() ? 0 : Infos[NextElt++]);
     OutputTable.push_back(IITDescriptor::get(IITDescriptor::PtrToArgument,
@@ -249,6 +261,7 @@ DecodeIITType(unsigned &NextElt, ArrayRef<unsigned char> Infos,
     OutputTable.push_back(IITDescriptor::get(IITDescriptor::PtrToElt, ArgInfo));
     return;
   }
+#endif
   case IIT_VEC_OF_ANYPTRS_TO_ELT: {
     unsigned short ArgNo = (NextElt == Infos.size() ? 0 : Infos[NextElt++]);
     unsigned short RefNo = (NextElt == Infos.size() ? 0 : Infos[NextElt++]);
@@ -337,6 +350,7 @@ static Type *DecodeFixedType(ArrayRef<Intrinsic::IITDescriptor> &Infos,
     }
     llvm_unreachable("unhandled");
   }
+#if VC_INTR_LLVM_VERSION_MAJOR < 17
   case IITDescriptor::PtrToArgument: {
     Type *Ty = Tys[D.getArgumentNumber()];
     return PointerType::getUnqual(Ty);
@@ -349,6 +363,7 @@ static Type *DecodeFixedType(ArrayRef<Intrinsic::IITDescriptor> &Infos,
     Type *EltTy = cast<VectorType>(VTy)->getElementType();
     return PointerType::getUnqual(EltTy);
   }
+#endif
   case IITDescriptor::VecOfAnyPtrsToElt:
     // Return the overloaded type (which determines the pointers address space)
     return Tys[D.getOverloadArgNumber()];
@@ -411,10 +426,14 @@ void GenXIntrinsic::getIntrinsicInfoTableEntries(
 /// parse ffXX as f(fXX) or f(fX)X.  (X is a placeholder for any other type.)
 static std::string getMangledTypeStr(Type *Ty) {
   std::string Result;
+  if (!Ty)
+    return Result;
   if (PointerType *PTyp = dyn_cast<PointerType>(Ty)) {
     Result += "p" + llvm::utostr(PTyp->getAddressSpace());
 #if VC_INTR_LLVM_VERSION_MAJOR >= 13
+#if VC_INTR_LLVM_VERSION_MAJOR < 18
     if (PTyp->isOpaque())
+#endif // VC_INTR_LLVM_VERSION_MAJOR < 18
       return Result;
 #endif // VC_INTR_LLVM_VERSION_MAJOR >= 13
     Result += getMangledTypeStr(VCINTR::Type::getNonOpaquePtrEltTy(PTyp));
@@ -437,10 +456,9 @@ static std::string getMangledTypeStr(Type *Ty) {
       Result += "vararg";
     // Ensure nested function types are distinguishable.
     Result += "f";
-  } else if (isa<VectorType>(Ty)) {
-    Result += "v" +
-              utostr(VCINTR::VectorType::getNumElements(cast<VectorType>(Ty))) +
-              getMangledTypeStr(cast<VectorType>(Ty)->getElementType());
+  } else if (auto *VTy = dyn_cast<VectorType>(Ty)) {
+    Result += "v" + utostr(VCINTR::VectorType::getNumElements(VTy)) +
+              getMangledTypeStr(VTy->getElementType());
 #if VC_INTR_LLVM_VERSION_MAJOR >= 16
   } else if (auto *TargetTy = dyn_cast<TargetExtType>(Ty)) {
     Result += "t_" + TargetTy->getName().str();
@@ -449,7 +467,7 @@ static std::string getMangledTypeStr(Type *Ty) {
     for (auto I : TargetTy->int_params())
       Result += "_" + llvm::utostr(I);
 #endif // VC_INTR_LLVM_VERSION_MAJOR >= 16
-  } else if (Ty) {
+  } else {
     Result += EVT::getEVT(Ty).getEVTString();
   }
 
