@@ -1,6 +1,6 @@
 /*========================== begin_copyright_notice ============================
 
-Copyright (C) 2020-2022 Intel Corporation
+Copyright (C) 2020-2024 Intel Corporation
 
 SPDX-License-Identifier: MIT
 
@@ -201,7 +201,7 @@ static SPIRVArgDesc parseSPIRVIRImageType(StringRef TyName) {
   return {ResultType, AccessTy};
 }
 
-static Optional<SPIRVArgDesc> parseIntelType(StringRef TyName) {
+static VCINTR::Optional<SPIRVArgDesc> parseIntelType(StringRef TyName) {
   if (!TyName.consume_front(IntelTypes::TypePrefix))
     return {};
 
@@ -213,7 +213,7 @@ static Optional<SPIRVArgDesc> parseIntelType(StringRef TyName) {
   return SPIRVArgDesc{MainType, AccType};
 }
 
-static Optional<SPIRVArgDesc> parseOCLType(StringRef TyName) {
+static VCINTR::Optional<SPIRVArgDesc> parseOCLType(StringRef TyName) {
   if (!TyName.consume_front(OCLTypes::TypePrefix))
     return {};
 
@@ -227,7 +227,7 @@ static Optional<SPIRVArgDesc> parseOCLType(StringRef TyName) {
   return parseImageType(TyName);
 }
 
-static Optional<SPIRVArgDesc> parseSPIRVIRType(StringRef TyName) {
+static VCINTR::Optional<SPIRVArgDesc> parseSPIRVIRType(StringRef TyName) {
   if (!TyName.consume_front(SPIRVIRTypes::TypePrefix))
     return {};
 
@@ -248,7 +248,7 @@ static Optional<SPIRVArgDesc> parseSPIRVIRType(StringRef TyName) {
 // SPVImageTy -> "Image." _..._{Dim}_..._{Arrayed}_..._{Acc}
 // Dim, Arrayed, Acc - literal operands matching OpTypeImage operands in SPIRV
 // Assume that "opencl." "spirv." and "intel.buffer" types are well-formed.
-static Optional<SPIRVArgDesc> parseOpaqueType(StringRef TyName) {
+static VCINTR::Optional<SPIRVArgDesc> parseOpaqueType(StringRef TyName) {
   if (auto MaybeIntelTy = parseIntelType(TyName))
     return VCINTR::getValue(MaybeIntelTy);
 
@@ -578,7 +578,7 @@ bool GenXSPIRVReaderAdaptorImpl::run(Module &M) {
   }
 
   rewriteKernelsTypes(M);
-  restoreSingleElementVectors(M);
+  SEVUtil(M).restoreSEVs();
 
   for (auto &&F : M)
     runOnFunction(F);
